Volume model registry
volume_model_registry.RdReturns a registry (metadata table) describing tree volume models available in CanadaForestAllometry. The registry is used by wrapper functions to (1) discover models, (2) select the best applicable model for a given tree, and (3) select the correct model function.